@@ -767,10 +767,7 @@ class GroupedLinearEinsum(nn.Module):
         x = x.view(new_shape)
         # The better way, but not supported by torchscript
         #     x = x.unflatten(-1, (self.groups, self.ws))  # [..., G, I/G]
-        # This is also not supported by tract:
-        #     x = torch.einsum("btgi,gih->btgh", x, self.weight)  # [..., G, H/G]
-        # Thus, lets to some manual reshaping and multiplication:
-        x = x.unsqueeze(-1).mul(self.weight.unsqueeze(0).unsqueeze(0)).sum(-2)
+        x = torch.einsum("btgi,gih->btgh", x, self.weight)  # [..., G, H/G]
         x = x.flatten(2, 3)  # [B, T, H]
         return x
 
